@@ -9,7 +9,7 @@ import unicodedata
 import urllib.parse
 from argparse import Namespace
 from pathlib import Path
-from typing import Optional, Tuple, Union
+from typing import Optional, Tuple, Union, List, Dict
 
 import git
 import importlib_resources
@@ -50,6 +50,13 @@ LEAGUE_SPARTAN_KERNING = 5 # In px
 LEAGUE_SPARTAN_AVERAGE_SPACING = 7 # Guess at average default spacing between letters, in px
 LEAGUE_SPARTAN_100_WIDTHS = {" ": 40.0, "A": 98.245, "B": 68.1875, "C": 83.97625, "D": 76.60875, "E": 55.205, "F": 55.79, "G": 91.57875, "H": 75.0875, "I": 21.98875, "J": 52.631254, "K": 87.83625, "L": 55.205, "M": 106.9, "N": 82.5725, "O": 97.1925, "P": 68.1875, "Q": 98.83, "R": 79.41599, "S": 72.63125, "T": 67.83625, "U": 75.32125, "V": 98.245, "W": 134.62, "X": 101.28625, "Y": 93.1, "Z": 86.19875, ".": 26.78375, ",": 26.78375, "/": 66.08125, "\\": 66.08125, "-": 37.66125, ":": 26.78375, ";": 26.78375, "’": 24.3275, "!": 26.78375, "?": 64.3275, "&": 101.87125, "0": 78.48, "1": 37.895, "2": 75.205, "3": 72.04625, "4": 79.29875, "5": 70.175, "6": 74.26875, "7": 76.95875, "8": 72.16375, "9": 74.26875}
 
+CONTRIBUTOR_BLOCK_TEMPLATE = """<dc:contributor id="CONTRIBUTOR_ID">CONTRIBUTOR_NAME</dc:contributor>
+		<meta property="file-as" refines="#CONTRIBUTOR_ID">CONTRIBUTOR_SORT</meta>
+		<meta property="se:name.person.full-name" refines="#CONTRIBUTOR_ID">CONTRIBUTOR_FULL_NAME</meta>
+		<meta property="se:url.encyclopedia.wikipedia" refines="#CONTRIBUTOR_ID">CONTRIBUTOR_WIKI_URL</meta>
+		<meta property="se:url.authority.nacoaf" refines="#CONTRIBUTOR_ID">CONTRIBUTOR_NACOAF_URL</meta>
+		<meta property="role" refines="#CONTRIBUTOR_ID" scheme="marc:relators">CONTRIBUTOR_MARC</meta>"""
+
 def _replace_in_file(file_path: Path, search: Union[str, list], replace: Union[str, list]) -> None:
 	"""
 	Helper function to replace in a file.
@@ -147,7 +154,7 @@ def _calculate_image_lines(string: str, target_height: int, canvas_width: int) -
 
 	return lines
 
-def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors: dict, title_string: str) -> str:
+def _generate_titlepage_svg(title: str, authors: List[str], contributors: dict, title_string: str) -> str:
 	"""
 	Generate a draft of the titlepage SVG.
 	The function tries to build the title with the widest line at the bottom, moving up.
@@ -163,12 +170,12 @@ def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors:
 	A string representing the complete SVG source code of the titlepage.
 	"""
 
+	# Don't include "anonymous" authors in the cover
+	authors = [author for author in authors if author.lower() != "anonymous"]
+
 	svg = ""
 	canvas_width = se.TITLEPAGE_WIDTH - (TITLEPAGE_HORIZONTAL_PADDING * 2)
 
-	if not isinstance(authors, list):
-		authors = [authors]
-
 	# Read our template SVG to get some values before we begin
 	with importlib_resources.open_text("se.data.templates", "titlepage.svg", encoding="utf-8") as file:
 		svg = file.read()
@@ -177,17 +184,17 @@ def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors:
 	svg = regex.sub(r"\s*<text.+</svg>", "</svg>", svg, flags=regex.DOTALL).strip()
 
 	# Calculate the title lines
-	title_lines = _calculate_image_lines(title.upper().replace("'", "’"), TITLEPAGE_TITLE_HEIGHT, canvas_width)
+	title_lines = _calculate_image_lines(title.upper(), TITLEPAGE_TITLE_HEIGHT, canvas_width)
 
 	# Calculate the author lines
 	authors_lines = []
 	for author in authors:
-		authors_lines.append(_calculate_image_lines(author.upper().replace("'", "’"), TITLEPAGE_AUTHOR_HEIGHT, canvas_width))
+		authors_lines.append(_calculate_image_lines(author.upper(), TITLEPAGE_AUTHOR_HEIGHT, canvas_width))
 
 	# Calculate the contributor lines
 	contributor_lines = []
 	for descriptor, contributor in contributors.items():
-		contributor_lines.append([descriptor, _calculate_image_lines(contributor.upper().replace("'", "’"), TITLEPAGE_CONTRIBUTOR_HEIGHT, canvas_width)])
+		contributor_lines.append([descriptor, _calculate_image_lines(contributor.upper(), TITLEPAGE_CONTRIBUTOR_HEIGHT, canvas_width)])
 
 	# Construct the output
 	text_elements = ""
@@ -202,7 +209,8 @@ def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors:
 	element_y -= TITLEPAGE_TITLE_MARGIN
 
 	# Add the author(s)
-	element_y += TITLEPAGE_AUTHOR_SPACING
+	if authors:
+		element_y += TITLEPAGE_AUTHOR_SPACING
 
 	for author_lines in authors_lines:
 		for line in author_lines:
@@ -210,7 +218,8 @@ def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors:
 			text_elements += f"\t<text class=\"author\" x=\"700\" y=\"{element_y:.0f}\">{line}</text>\n"
 			element_y += TITLEPAGE_AUTHOR_MARGIN
 
-	element_y -= TITLEPAGE_AUTHOR_MARGIN
+	if authors:
+		element_y -= TITLEPAGE_AUTHOR_MARGIN
 
 	# Add the contributor(s)
 	if contributor_lines:
@@ -242,7 +251,7 @@ def _generate_titlepage_svg(title: str, authors: Union[str, list], contributors:
 
 	return svg
 
-def _generate_cover_svg(title: str, authors: Union[str, list], title_string: str) -> str:
+def _generate_cover_svg(title: str, authors: List[str], title_string: str) -> str:
 	"""
 	Generate a draft of the cover SVG.
 	The function tries to build the title box with the widest line at the bottom, moving up.
@@ -257,16 +266,12 @@ def _generate_cover_svg(title: str, authors: Union[str, list], title_string: str
 	A string representing the complete SVG source code of the cover page.
 	"""
 
+	# Don't include "anonymous" authors in the cover
+	authors = [author for author in authors if author.lower() != "anonymous"]
+
 	svg = ""
 	canvas_width = COVER_TITLE_BOX_WIDTH - (COVER_TITLE_BOX_PADDING * 2)
 
-	if not isinstance(authors, list):
-		authors = [authors]
-
-	title = title.replace("'", "’")
-	authors = [author.replace("'", "’") for author in authors]
-	title_string = title_string.replace("'", "’")
-
 	# Read our template SVG to get some values before we begin
 	with importlib_resources.open_text("se.data.templates", "cover.svg", encoding="utf-8") as file:
 		svg = file.read()
@@ -296,11 +301,14 @@ def _generate_cover_svg(title: str, authors: Union[str, list], title_string: str
 
 	# Construct the output
 	text_elements = ""
+	spacing = COVER_AUTHOR_SPACING
+	if not authors:
+		spacing = 0
 	element_y = COVER_TITLE_BOX_Y + \
 		+ ((COVER_TITLE_BOX_HEIGHT \
 			- ((len(title_lines) * title_height) \
 				+ ((len(title_lines) - 1) * COVER_TITLE_MARGIN) \
-				+ COVER_AUTHOR_SPACING \
+				+ spacing \
 				+ (len(authors_lines) * COVER_AUTHOR_HEIGHT) \
 		)) / 2)
 
@@ -313,15 +321,16 @@ def _generate_cover_svg(title: str, authors: Union[str, list], title_string: str
 	element_y -= COVER_TITLE_MARGIN
 
 	# Add the author(s)
-	element_y += COVER_AUTHOR_SPACING
+	if authors:
+		element_y += COVER_AUTHOR_SPACING
 
-	for author_lines in authors_lines:
-		for line in author_lines:
-			element_y += COVER_AUTHOR_HEIGHT
-			text_elements += f"\t<text class=\"author\" x=\"700\" y=\"{element_y:.0f}\">{line}</text>\n"
-			element_y += COVER_AUTHOR_MARGIN
+		for author_lines in authors_lines:
+			for line in author_lines:
+				element_y += COVER_AUTHOR_HEIGHT
+				text_elements += f"\t<text class=\"author\" x=\"700\" y=\"{element_y:.0f}\">{line}</text>\n"
+				element_y += COVER_AUTHOR_MARGIN
 
-	element_y -= COVER_AUTHOR_MARGIN
+		element_y -= COVER_AUTHOR_MARGIN
 
 	# Remove unused CSS
 	if title_class != "title":
@@ -385,24 +394,175 @@ def _copy_template_file(filename: str, dest_path: Path) -> None:
 	with importlib_resources.path("se.data.templates", filename) as src_path:
 		shutil.copy(src_path, dest_path)
 
+def _generate_contributor_string(contributors: List[Dict], include_xhtml: bool) -> str:
+	"""
+	Given a list of contributors, generate a contributor string like `Bob Smith, Jane Doe, and Sam Johnson`.
+	With include_xhtml, the string looks like: `<b class="name">Bob Smith</b>, <a href="https://en.wikipedia.org/wiki/Jane_Doe">Jane Doe</a>, and <b class="name">Sam Johnson</b>`
+
+	INPUTS
+	contributors: A list of contributor dicts
+	include_xhtml: Include <b> or <a> for each contributor, making the output suitable for the coloiphon
+
+	OUTPUTS
+	A string of XML representing the contributors
+	"""
+
+	output = ""
+
+	# Don't include "anonymous" contributors
+	contributors = [contributor for contributor in contributors if contributor["name"].lower() != "anonymous"]
+
+	if len(contributors) == 1:
+		if include_xhtml:
+			if contributors[0]["wiki_url"]:
+				output += f"<a href=\"{contributors[0]['wiki_url']}\">{contributors[0]['name']}</a>"
+			else:
+				output += f"<b class=\"name\">{contributors[0]['name']}</b>"
+		else:
+			output += contributors[0]["name"]
+
+	elif len(contributors) == 2:
+		if include_xhtml:
+			if contributors[0]["wiki_url"]:
+				output += f"<a href=\"{contributors[0]['wiki_url']}\">{contributors[0]['name']}</a>"
+			else:
+				output += f"<b class=\"name\">{contributors[0]['name']}</b>"
+
+			output += " and "
+
+			if contributors[1]["wiki_url"]:
+				output += f"<a href=\"{contributors[1]['wiki_url']}\">{contributors[1]['name']}</a>"
+			else:
+				output += f"<b class=\"name\">{contributors[1]['name']}</b>"
+		else:
+			output += contributors[0]["name"] + " and " + contributors[1]["name"]
+
+	else:
+		for i, contributor in enumerate(contributors):
+			if 0 < i <= len(contributors) - 2:
+				output += ", "
+
+			if i > 0 and i == len(contributors) - 1:
+				output += ", and "
+
+			if include_xhtml:
+				if contributor["wiki_url"]:
+					output += f"<a href=\"{contributor['wiki_url']}\">{contributor['name']}</a>"
+				else:
+					output += f"<b class=\"name\">{contributor['name']}</b>"
+			else:
+				output += contributor["name"]
+
+	return output
+
+def _generate_metadata_contributor_xml(contributors: List[Dict], contributor_type: str) -> str:
+	"""
+	Given a list of contributors, generate a metadata XML block.
+
+	INPUTS
+	contributors: A list of contributor dicts
+	contributor_type: Either `author`, `translator`, or `illustrator`
+
+	OUTPUTS
+	A string of XML representing the contributor block
+	"""
+
+	output = ""
+
+	for i, contributor in enumerate(contributors):
+		contributor_block = CONTRIBUTOR_BLOCK_TEMPLATE
+
+		if contributor["wiki_url"]:
+			contributor_block = contributor_block.replace(">CONTRIBUTOR_WIKI_URL<", f">{contributor['wiki_url']}<")
+
+		if contributor["nacoaf_url"]:
+			contributor_block = contributor_block.replace(">CONTRIBUTOR_NACOAF_URL<", f">{contributor['nacoaf_url']}<")
+
+		# Make an attempt at figuring out the file-as name. We check for some common two-word last names.
+		matches = regex.findall(r"^(.+?)\s+((?:(?:Da|Das|De|Del|Della|Di|Du|El|La|Le|Van|Van Der|Von)\s+)?[^\s]+)$", contributor["name"])
+		if matches:
+			contributor_block = contributor_block.replace(">CONTRIBUTOR_SORT<", f">{matches[0][1]}, {matches[0][0]}<")
+
+		if contributor["name"].lower() == "anonymous":
+			contributor_block = contributor_block.replace(">CONTRIBUTOR_SORT<", ">Anonymous<")
+			contributor_block = contributor_block.replace("""<meta property="se:name.person.full-name" refines="#ID">CONTRIBUTOR_FULL_NAME</meta>""", "")
+			contributor_block = contributor_block.replace("""<meta property="se:url.encyclopedia.wikipedia" refines="#ID">CONTRIBUTOR_WIKI_URL</meta>""", "")
+			contributor_block = contributor_block.replace("""<meta property="se:url.authority.nacoaf" refines="#ID">CONTRIBUTOR_NACOAF_URL</meta>""", "")
+
+		contributor_block = contributor_block.replace(">CONTRIBUTOR_NAME<", f">{contributor['name']}<")
+		contributor_block = contributor_block.replace("id=\"CONTRIBUTOR_ID\"", f"id=\"{contributor_type}-{i + 1}\"")
+		contributor_block = contributor_block.replace("#CONTRIBUTOR_ID", f"#{contributor_type}-{i + 1}")
+
+		if contributor_type == "author":
+			contributor_block = contributor_block.replace("CONTRIBUTOR_MARC", "aut")
+
+		if contributor_type == "translator":
+			contributor_block = contributor_block.replace("CONTRIBUTOR_MARC", "trl")
+
+		if contributor_type == "illustrator":
+			contributor_block = contributor_block.replace("CONTRIBUTOR_MARC", "ill")
+
+		output += contributor_block + "\n\t\t"
+
+	if len(contributors) == 1:
+		output = output.replace(f"{contributor_type}-1", contributor_type)
+
+	return output.strip()
+
 def _create_draft(args: Namespace):
 	"""
 	Implementation for `se create-draft`
 	"""
 
 	# Put together some variables for later use
-	identifier = se.formatting.make_url_safe(args.author) + "/" + se.formatting.make_url_safe(args.title)
-	title_string = args.title.replace("'", "’") + ", by " + args.author.replace("'", "’")
-	sorted_title = regex.sub(r"^(A|An|The) (.+)$", "\\2, \\1", args.title)
+	authors = []
+	translators = []
+	illustrators = []
 	pg_producers = []
+	title = args.title.replace("'", "’")
+
+	for author in args.author:
+		authors.append({"name": author.replace("'", "’"), "wiki_url": None, "nacoaf_url": None})
 
 	if args.translator:
-		identifier = identifier + "/" + se.formatting.make_url_safe(args.translator)
-		title_string = title_string + ". Translated by " + args.translator
+		for translator in args.translator:
+			translators.append({"name": translator.replace("'", "’"), "wiki_url": None, "nacoaf_url": None})
 
 	if args.illustrator:
-		identifier = identifier + "/" + se.formatting.make_url_safe(args.illustrator)
-		title_string = title_string + ". Illustrated by " + args.illustrator
+		for illustrator in args.illustrator:
+			illustrators.append({"name": illustrator.replace("'", "’"), "wiki_url": None, "nacoaf_url": None})
+
+	title_string = title
+	if authors and authors[0]["name"].lower() != "anonymous":
+		title_string += ", by " + _generate_contributor_string(authors, False)
+
+	identifier = ""
+	for author in authors:
+		identifier += se.formatting.make_url_safe(author["name"]) + "_"
+
+	identifier = identifier.rstrip("_") + "/" + se.formatting.make_url_safe(title)
+
+	sorted_title = regex.sub(r"^(A|An|The) (.+)$", "\\2, \\1", title)
+
+	if translators:
+		title_string = title_string + ". Translated by " + _generate_contributor_string(translators, False)
+
+		identifier = identifier + "/"
+
+		for translator in translators:
+			identifier += se.formatting.make_url_safe(translator["name"]) + "_"
+
+		identifier = identifier.rstrip("_")
+
+	if illustrators:
+		title_string = title_string + ". Illustrated by " + _generate_contributor_string(illustrators, False)
+
+		identifier = identifier + "/"
+
+		for illustrator in illustrators:
+			identifier += se.formatting.make_url_safe(illustrator["name"]) + "_"
+
+		identifier = identifier.rstrip("_")
 
 	repo_name = identifier.replace("/", "_")
 
@@ -411,6 +571,21 @@ def _create_draft(args: Namespace):
 	if repo_path.is_dir():
 		raise se.InvalidInputException(f"Directory already exists: [path][link=file://{repo_path}]{repo_path}[/][/].")
 
+	# Get data on authors
+	for i, author in enumerate(authors):
+		if not args.offline and author["name"].lower() != "anonymous":
+			author["wiki_url"], author["nacoaf_url"] = _get_wikipedia_url(author["name"], True)
+
+	# Get data on translators
+	for i, translator in enumerate(translators):
+		if not args.offline and translator["name"].lower() != "anonymous":
+			translator["wiki_url"], translator["nacoaf_url"] = _get_wikipedia_url(translator["name"], True)
+
+	# Get data on illlustrators
+	for i, illustrator in enumerate(illustrators):
+		if not args.offline and illustrator["name"].lower() != "anonymous":
+			illustrator["wiki_url"], illustrator["nacoaf_url"] = _get_wikipedia_url(illustrator["name"], True)
+
 	# Download PG HTML and do some fixups
 	if args.pg_url:
 		if args.offline:
@@ -534,7 +709,6 @@ def _create_draft(args: Namespace):
 			se.quiet_remove(repo_path / "src" / "epub" / "text" / "body.xhtml")
 
 	# Copy over templates
-
 	_copy_template_file("gitignore", repo_path / ".gitignore")
 	_copy_template_file("LICENSE.md", repo_path)
 	_copy_template_file("container.xml", repo_path / "src" / "META-INF")
@@ -555,21 +729,11 @@ def _create_draft(args: Namespace):
 	_copy_template_file("cover.svg", repo_path / "images" / "cover.svg")
 
 	# Try to find Wikipedia links if possible
-	if args.offline:
-		author_wiki_url = None
-		author_nacoaf_url = None
-		ebook_wiki_url = None
-		translator_wiki_url = None
-		translator_nacoaf_url = None
-	else:
-		author_wiki_url, author_nacoaf_url = _get_wikipedia_url(args.author, True)
-		ebook_wiki_url = None
-		if args.title != "Short Fiction":
-			# There's a "Short Fiction" Wikipedia article, so make an exception for that case
-			ebook_wiki_url, _ = _get_wikipedia_url(args.title, False)
-		translator_wiki_url = None
-		if args.translator:
-			translator_wiki_url, translator_nacoaf_url = _get_wikipedia_url(args.translator, True)
+	ebook_wiki_url = None
+
+	if not args.offline and title != "Short Fiction":
+		# There's a "Short Fiction" Wikipedia article, so make an exception for that case
+		ebook_wiki_url, _ = _get_wikipedia_url(title, False)
 
 	# Pre-fill a few templates
 	_replace_in_file(repo_path / "src" / "epub" / "text" / "titlepage.xhtml", "TITLE_STRING", title_string)
@@ -579,17 +743,17 @@ def _create_draft(args: Namespace):
 	# Create the titlepage SVG
 	contributors = {}
 	if args.translator:
-		contributors["translated by"] = args.translator
+		contributors["translated by"] = _generate_contributor_string(translators, False)
 
 	if args.illustrator:
-		contributors["illustrated by"] = args.illustrator
+		contributors["illustrated by"] = _generate_contributor_string(illustrators, False)
 
 	with open(repo_path / "images" / "titlepage.svg", "w", encoding="utf-8") as file:
-		file.write(_generate_titlepage_svg(args.title, args.author, contributors, title_string))
+		file.write(_generate_titlepage_svg(title, [author["name"] for author in authors], contributors, title_string))
 
 	# Create the cover SVG
 	with open(repo_path / "images" / "cover.svg", "w", encoding="utf-8") as file:
-		file.write(_generate_cover_svg(args.title, args.author, title_string))
+		file.write(_generate_cover_svg(title, [author["name"] for author in authors], title_string))
 
 	# Build the cover/titlepage for distribution
 	epub = SeEpub(repo_path)
@@ -599,15 +763,17 @@ def _create_draft(args: Namespace):
 	if args.pg_url:
 		_replace_in_file(repo_path / "src" / "epub" / "text" / "imprint.xhtml", "PG_URL", args.pg_url)
 
+	# Fill out the colophon
 	with open(repo_path / "src" / "epub" / "text" / "colophon.xhtml", "r+", encoding="utf-8") as file:
 		colophon_xhtml = file.read()
 
 		colophon_xhtml = colophon_xhtml.replace("SE_IDENTIFIER", identifier)
-		colophon_xhtml = colophon_xhtml.replace(">AUTHOR<", f">{args.author}<")
-		colophon_xhtml = colophon_xhtml.replace("TITLE", args.title)
+		colophon_xhtml = colophon_xhtml.replace("TITLE", title)
+		colophon_xhtml = colophon_xhtml.replace("<a href=\"AUTHOR_WIKI_URL\">AUTHOR</a>", _generate_contributor_string(authors, True))
 
-		if author_wiki_url:
-			colophon_xhtml = colophon_xhtml.replace("AUTHOR_WIKI_URL", author_wiki_url)
+		if translators:
+			translator_block = f"It was translated from ORIGINAL_LANGUAGE in TRANSLATION_YEAR by<br/>\n\t\t\t{_generate_contributor_string(translators, True)}.</p>"
+			colophon_xhtml = colophon_xhtml.replace("<p>This ebook was produced for the<br/>", f"{translator_block}\n\t\t\t<p>This ebook was produced for the<br/>")
 
 		if args.pg_url:
 			colophon_xhtml = colophon_xhtml.replace("PG_URL", args.pg_url)
@@ -639,13 +805,13 @@ def _create_draft(args: Namespace):
 		file.write(colophon_xhtml)
 		file.truncate()
 
+	# Fill out the metadata file
 	with open(repo_path / "src" / "epub" / "content.opf", "r+", encoding="utf-8") as file:
 		metadata_xml = file.read()
 
 		metadata_xml = metadata_xml.replace("SE_IDENTIFIER", identifier)
-		metadata_xml = metadata_xml.replace(">AUTHOR<", f">{args.author}<")
 		metadata_xml = metadata_xml.replace(">TITLE_SORT<", f">{sorted_title}<")
-		metadata_xml = metadata_xml.replace(">TITLE<", f">{args.title}<")
+		metadata_xml = metadata_xml.replace(">TITLE<", f">{title}<")
 		metadata_xml = metadata_xml.replace("VCS_IDENTIFIER", str(repo_name))
 
 		if pg_producers:
@@ -665,25 +831,24 @@ def _create_draft(args: Namespace):
 
 			metadata_xml = regex.sub(r"\t\t<dc:contributor id=\"transcriber-1\">TRANSCRIBER</dc:contributor>\s*<meta property=\"file-as\" refines=\"#transcriber-1\">TRANSCRIBER_SORT</meta>\s*<meta property=\"se:url.homepage\" refines=\"#transcriber-1\">TRANSCRIBER_URL</meta>\s*<meta property=\"role\" refines=\"#transcriber-1\" scheme=\"marc:relators\">trc</meta>", "\t\t" + producers_xhtml.strip(), metadata_xml, flags=regex.DOTALL)
 
-		if author_wiki_url:
-			metadata_xml = metadata_xml.replace(">AUTHOR_WIKI_URL<", f">{author_wiki_url}<")
-
-		if author_nacoaf_url:
-			metadata_xml = metadata_xml.replace(">AUTHOR_NACOAF_URL<", f">{author_nacoaf_url}<")
-
 		if ebook_wiki_url:
 			metadata_xml = metadata_xml.replace(">EBOOK_WIKI_URL<", f">{ebook_wiki_url}<")
 
-		if args.translator:
-			metadata_xml = metadata_xml.replace(">TRANSLATOR<", f">{args.translator}<")
+		authors_xml = _generate_metadata_contributor_xml(authors, "author")
+		authors_xml = authors_xml.replace("dc:contributor", "dc:creator")
+		metadata_xml = regex.sub(r"<dc:creator id=\"author\">AUTHOR</dc:creator>.+?scheme=\"marc:relators\">aut</meta>", authors_xml, metadata_xml, flags=regex.DOTALL)
 
-			if translator_wiki_url:
-				metadata_xml = metadata_xml.replace(">TRANSLATOR_WIKI_URL<", f">{translator_wiki_url}<")
-
-			if translator_nacoaf_url:
-				metadata_xml = metadata_xml.replace(">TRANSLATOR_NACOAF_URL<", f">{translator_nacoaf_url}<")
+		if translators:
+			translators_xml = _generate_metadata_contributor_xml(translators, "translator")
+			metadata_xml = regex.sub(r"<dc:contributor id=\"translator\">.+?scheme=\"marc:relators\">trl</meta>", translators_xml, metadata_xml, flags=regex.DOTALL)
 		else:
-			metadata_xml = regex.sub(r"<dc:contributor id=\"translator\">.+?<dc:contributor id=\"artist\">", "<dc:contributor id=\"artist\">", metadata_xml, flags=regex.DOTALL)
+			metadata_xml = regex.sub(r"<dc:contributor id=\"translator\">.+?scheme=\"marc:relators\">trl</meta>", "", metadata_xml, flags=regex.DOTALL)
+
+		if illustrators:
+			illustrators_xml = _generate_metadata_contributor_xml(illustrators, "illustrator")
+			metadata_xml = regex.sub(r"<dc:contributor id=\"illustrator\">.+?scheme=\"marc:relators\">ill</meta>", illustrators_xml, metadata_xml, flags=regex.DOTALL)
+		else:
+			metadata_xml = regex.sub(r"<dc:contributor id=\"illustrator\">.+?scheme=\"marc:relators\">ill</meta>", "", metadata_xml, flags=regex.DOTALL)
 
 		if args.pg_url:
 			if pg_subjects:
@@ -741,12 +906,12 @@ def create_draft() -> int:
 	"""
 
 	parser = argparse.ArgumentParser(description="Create a skeleton of a new Standard Ebook in the current directory.")
-	parser.add_argument("-i", "--illustrator", dest="illustrator", help="the illustrator of the ebook")
-	parser.add_argument("-r", "--translator", dest="translator", help="the translator of the ebook")
+	parser.add_argument("-i", "--illustrator", dest="illustrator", nargs="+", help="an illustrator of the ebook")
+	parser.add_argument("-r", "--translator", dest="translator", nargs="+", help="a translator of the ebook")
 	parser.add_argument("-p", "--pg-url", dest="pg_url", help="the URL of the Project Gutenberg ebook to download")
 	parser.add_argument("-e", "--email", dest="email", help="use this email address as the main committer for the local Git repository")
 	parser.add_argument("-o", "--offline", dest="offline", action="store_true", help="create draft without network access")
-	parser.add_argument("-a", "--author", dest="author", required=True, help="the author of the ebook")
+	parser.add_argument("-a", "--author", dest="author", required=True, nargs="+", help="an author of the ebook")
 	parser.add_argument("-t", "--title", dest="title", required=True, help="the title of the ebook")
 	args = parser.parse_args()
 
