@@ -325,9 +325,12 @@ class SeEpub:
 		"""
 
 		# Quick sanity check before we begin
-		if not section.get_attr("id") or (section.parent.lxml_element.tag != "body" and not section.parent.get_attr("id")):
+		if not section.get_attr("id") or (section.parent.tag.lower() != "body" and not section.parent.get_attr("id")):
 			raise se.InvalidXhtmlException("Section without [attr]id[/] attribute.")
 
+		if section.parent.tag.lower() == "body":
+			section.set_attr("epub:type", f"{section.get_attr('epub:type')} {section.parent.get_attr('epub:type')}".strip())
+
 		# Try to find our parent tag in the output, by ID.
 		# If it's not in the output, then append it to the tag's closest parent by ID (or <body>), then iterate over its children and do the same.
 		existing_section = output_dom.xpath(f"//*[@id='{section.get_attr('id')}']")
@@ -426,7 +429,10 @@ class SeEpub:
 				dom = se.formatting.EasyXhtmlTree(file.read())
 
 				for node in dom.xpath("/html/body/*"):
-					self._recompose_xhtml(node, output_dom)
+					try:
+						self._recompose_xhtml(node, output_dom)
+					except se.SeException as ex:
+						raise se.SeException(f"[path][link=file://{self.path / 'src/epub/' / filename}]{filename}[/][/]: {ex}") from ex
 
 		# Add the ToC after the titlepage
 		with open(self.path / "src" / "epub" / "toc.xhtml", "r", encoding="utf-8") as file:
@@ -1002,17 +1008,16 @@ class SeEpub:
 
 			# If we need to write back the body text file
 			if needs_rewrite:
-				new_file = open(file_path, "w")
-				new_file.write(se.formatting.format_xhtml(dom.to_string()))
-				new_file.close()
+				with open(file_path, "w") as file:
+					file.write(se.formatting.format_xhtml(dom.to_string()))
 
 		if processed == 0:
 			raise se.InvalidInputException("No files processed. Did you update the manifest and order the spine?")
 
 		if notes_changed > 0:
 			# Now we need to recreate the endnotes file
-			for ol_tag in self._endnotes_dom.xpath("/html/body/section[contains(@epub:type, 'endnotes')]/ol[1]"):
-				for node in ol_tag.xpath("./li[contains(@epub:type, 'endnote')]"):
+			for ol_node in self._endnotes_dom.xpath("/html/body/section[contains(@epub:type, 'endnotes')]/ol[1]"):
+				for node in ol_node.xpath("./li[contains(@epub:type, 'endnote')]"):
 					node.remove()
 
 				self.endnotes.sort(key=lambda endnote: endnote.number)
@@ -1024,7 +1029,7 @@ class SeEpub:
 						for node in endnote.node.xpath(".//a[contains(@epub:type, 'backlink')]"):
 							node.set_attr("href", f"{endnote.source_file}#noteref-{endnote.number}")
 
-						ol_tag.append(endnote.node)
+						ol_node.append(endnote.node)
 
 			with open(self.path / "src" / "epub" / "text" / "endnotes.xhtml", "w") as file:
 				file.write(se.formatting.format_xhtml(self._endnotes_dom.to_string()))
