@@ -228,13 +228,11 @@ def build(self, run_epubcheck: bool, build_kobo: bool, build_kindle: bool, outpu
 									selector = selector.replace(split_selector[1], "." + replacement_class, 1)
 									sel = se.easy_xml.css_selector(target_element_selector)
 									for element in tree.xpath(sel.path, namespaces=se.XHTML_NAMESPACES):
-										current_class = element.get("class")
-										if current_class is not None and replacement_class not in current_class:
-											current_class = current_class + " " + replacement_class
-										else:
-											current_class = replacement_class
+										current_class = element.get("class", "")
 
-										element.set("class", current_class)
+										if replacement_class not in current_class:
+											current_class = f"{current_class} {replacement_class}".strip()
+											element.set("class", current_class)
 
 						except lxml.cssselect.ExpressionError:
 							# This gets thrown if we use pseudo-elements, which lxml doesn't support
@@ -528,7 +526,7 @@ def build(self, run_epubcheck: bool, build_kobo: bool, build_kindle: bool, outpu
 						processed_xhtml = regex.sub(r"""\s*epub:type=""\s*""", "", processed_xhtml)
 
 						# Move quotation marks over periods and commas
-						processed_xhtml = regex.sub(r"([\\.,])([’”])", r"""\1<span class="quote-align">\2</span>""", processed_xhtml)
+						processed_xhtml = regex.sub(fr"([\\.…,])([’”{se.HAIR_SPACE}]+)", r"""\1<span class="quote-align">\2</span>""", processed_xhtml)
 
 						# The above replacement may replace text within <img alt> attributes. Remove those now until no replacements remain, since we may have
 						# many matches in the same line
@@ -607,20 +605,19 @@ def build(self, run_epubcheck: bool, build_kobo: bool, build_kindle: bool, outpu
 								# Note that we replaced ↩ with \u21a9\ufe0e in an earlier iOS compatibility fix
 								xhtml = regex.sub(r"epub:type=\"backlink\">\u21a9\ufe0e</a>", "epub:type=\"backlink\">←</a>", xhtml)
 
-							# We have to remove the default namespace declaration from our document, otherwise
-							# xpath won't find anything at all.  See http://stackoverflow.com/questions/297239/why-doesnt-xpath-work-when-processing-an-xhtml-document-with-lxml-in-python
-							try:
-								tree = etree.fromstring(str.encode(xhtml.replace(" xmlns=\"http://www.w3.org/1999/xhtml\"", "")))
-							except Exception as ex:
-								raise se.InvalidXhtmlException(f"Error parsing XHTML file: [path][link=file://{filename}]{filename}[/][/]. Exception: {ex}")
+							dom = se.easy_xml.EasyXhtmlTree(xhtml)
 
-							kobo.add_kobo_spans_to_node(tree.xpath("./body", namespaces=se.XHTML_NAMESPACES)[0])
+							# Remove quote-align spans we inserted above, since Kobo has weird spacing problems with them
+							for node in dom.xpath("/html/body//span[contains(@class, 'quote-align')]"):
+								node.unwrap()
 
-							xhtml = etree.tostring(tree, encoding="unicode", pretty_print=True, with_tail=False)
-							xhtml = regex.sub(r"<html:span", "<span", xhtml)
+							# Now add the kobo spans
+							kobo.add_kobo_spans_to_node(dom.xpath("/html/body")[0].lxml_element)
+
+							# Clean up output
+							xhtml = dom.to_string()
+							xhtml = regex.sub(r"<html:span xmlns:html=\"http://www\.w3\.org/1999/xhtml\"", "<span", xhtml)
 							xhtml = regex.sub(r"html:span>", "span>", xhtml)
-							xhtml = regex.sub(r"<span xmlns:html=\"http://www.w3.org/1999/xhtml\"", "<span", xhtml)
-							xhtml = regex.sub(r"<html", "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n<html xmlns=\"http://www.w3.org/1999/xhtml\"", xhtml)
 
 							file.seek(0)
 							file.write(xhtml)
