@@ -288,6 +288,8 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b[eé]migr[eé](?!e)", r"émigré", xhtml)			# emigre -> émigré (but not emigrée, which is French)
 	xhtml = regex.sub(r"\b([Cc])ourtezan", r"\1ourtesan", xhtml)			# courtezan -> courtesan
 	xhtml = regex.sub(r"\b([Cc])ompleat", r"\1omplete", xhtml)			# compleat -> complete
+	xhtml = regex.sub(r"\b([Dd])umfound", r"\1umbfound", xhtml)			# dumfound -> dumbfound
+	xhtml = regex.sub(r"\b’([Cc])ello(s?)\b", r"\1ello\2", xhtml)			# 'cello -> cello
 
 	# Normalize some names
 	xhtml = regex.sub(r"Moliere", r"Molière", xhtml)				# Moliere -> Molière
@@ -304,7 +306,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\bPekin\b", r"Peking", xhtml)				# Pekin -> Peking
 	xhtml = regex.sub(r"\bBuenos Ayres\b", r"Buenos Aires", xhtml)			# Buenos Ayres -> Buenos Aires
 	xhtml = regex.sub(r"\bCracow", r"Krakow", xhtml)				# Cracow -> Krakow
-	xhtml = regex.sub(r"\bKief", r"Kiev", xhtml)					# Kief -> Kiev
+	xhtml = regex.sub(r"\bKieff?\b", r"Kiev", xhtml)				# Kief -> Kiev
 	xhtml = regex.sub(r"\bRoumanian", r"Romanian", xhtml)				# Roumanian -> Romanian
 	xhtml = regex.sub(r"\b([Rr])enascence", r"\1enaissance", xhtml)			# renascence -> renaissance
 	xhtml = regex.sub(r"\bThibet", r"Tibet", xhtml)					# Thibet -> Tibet
@@ -335,7 +337,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r" n’t\b", "n’t", xhtml)
 
 	# Remove roman ordinals
-	xhtml = regex.sub(r"<span epub:type=\"z3998:roman\">(.*?)</span>(st|nd|rd|th)\b", r"<span epub:type=\"z3998:roman\">\1</span>", xhtml)
+	xhtml = regex.sub(r"<span epub:type=\"z3998:roman\">(.*?)</span>(st|nd|rd|th)\b", r'<span epub:type="z3998:roman">\1</span>', xhtml)
 
 	# X-ray is always capitalized. Match a preceding space so that we don't catch it in an ID attribute.
 	xhtml = regex.sub(r"(\s)x-ray", r"\1X-ray", xhtml)
